matchCohortsByAge.Rd
Function for matching the control to target by age
matchCohortsByAge(cdm, sourceTable, tableToMatch, maxAllowedAgeDifference = 0)
Connection to the database (package CDMConnector)
Table which is used as reference for matching
Table which is matched
Value for maximum allowed age difference to be mapped to