Skip to contents

Function for discovering ngrams from the extracted data from CohortContrast function

Usage

nGramDiscovery(data, collapse_size = 0)

Arguments

data

CohortContrastObject returned by CohortContrast or GUI snapshot

collapse_size

integer for days to use for collapse same concept ids