Function for discovering ngrams from the extracted data from CohortContrast function
nGramDiscovery.RdFunction for discovering ngrams from the extracted data from CohortContrast function
nGramDiscovery.RdFunction for discovering ngrams from the extracted data from CohortContrast function